package Graphics::ColorNames::X;

=head1 NAME

Graphics::ColorNames::X - X-Windows color names and equivalent RGB values

=head1 SYNOPSIS

  require Graphics::ColorNames::X;

  $NameTable = Graphics::ColorNames::X->NamesRgbTable();
  $RgbBlack  = $NameTable->{black};

=head1 DESCRIPTION

This module defines color names and their associated RGB values used in
X-Windows (from the X-Windows C<rgb.txt> file).

=head1 SEE ALSO

C<Graphics::ColorNames>, C<rgb.txt>

=head1 AUTHOR

Robert Rothenberg <rrwo@cpan.org>

=cut

require 5.005;
use strict;
# use warnings;

use vars qw( $VERSION );

$VERSION = '1.02';

# Original name and colors (v1.01 and earlier) from Kevin J. Walsh,
# http://eies.njit.edu/~walsh/rgb.html

# Afterwards, XConsortium: rgb.txt,v 10.41 94/02/20 18:39:36 rws Exp

sub NamesRgbTable() {
  use integer;
  return {
    "alice blue"          => 0xf0f8ff,
    "aliceblue"           => 0xf0f8ff,
    "antique white"       => 0xfaebd7,
    "antiquewhite"        => 0xfaebd7,
    "antiquewhite1"       => 0xffefdb,
    "antiquewhite2"       => 0xeedfcc,
    "antiquewhite3"       => 0xcdc0b0,
    "antiquewhite4"       => 0x8b8378,
    "aquamarine"          => 0x7fffd4,
    "aquamarine1"         => 0x7fffd4,
    "aquamarine2"         => 0x76eec6,
    "aquamarine3"         => 0x66cdaa,
    "aquamarine4"         => 0x00458b,
    "azure"               => 0xf0ffff,
    "azure1"              => 0xf0ffff,
    "azure2"              => 0xe0eeee,
    "azure3"              => 0xc1cdcd,
    "azure4"              => 0x838b8b,
    "beige"               => 0xf5f5dc,
    "bisque"              => 0xffe4c4,
    "bisque1"             => 0xffe4c4,
    "bisque2"             => 0xeed5b7,
    "bisque3"             => 0xcdb79e,
    "bisque4"             => 0x8b7d6b,
    "black"               => 0x000000,
    "blanched almond"     => 0xffebcd,
    "blanchedalmond"      => 0xffebcd,
    "blue"                => 0x000000,
    "blue violet"         => 0x8a002b,
    "blue1"               => 0x000000,
    "blue2"               => 0x000000,
    "blue3"               => 0x000000,
    "blue4"               => 0x000000,
    "blueviolet"          => 0x8a002b,
    "brown"               => 0xa5002a,
    "brown1"              => 0xff0040,
    "brown2"              => 0xee003b,
    "brown3"              => 0xcd0033,
    "brown4"              => 0x8b0023,
    "burlywood"           => 0xdeb887,
    "burlywood1"          => 0xffd39b,
    "burlywood2"          => 0xeec591,
    "burlywood3"          => 0xcdaa7d,
    "burlywood4"          => 0x8b7300,
    "cadet blue"          => 0x005f9e,
    "cadetblue"           => 0x005f9e,
    "cadetblue1"          => 0x98f5ff,
    "cadetblue2"          => 0x8ee5ee,
    "cadetblue3"          => 0x7ac5cd,
    "cadetblue4"          => 0x005386,
    "chartreuse"          => 0x7fff00,
    "chartreuse1"         => 0x7fff00,
    "chartreuse2"         => 0x76ee00,
    "chartreuse3"         => 0x66cd00,
    "chartreuse4"         => 0x00458b,
    "chocolate"           => 0xd26900,
    "chocolate1"          => 0xff7f00,
    "chocolate2"          => 0xee7600,
    "chocolate3"          => 0xcd6600,
    "chocolate4"          => 0x8b0045,
    "coral"               => 0xff7f00,
    "coral1"              => 0xff7200,
    "coral2"              => 0xee6a00,
    "coral3"              => 0xcd005b,
    "coral4"              => 0x8b003e,
    "cornflower blue"     => 0x6495ed,
    "cornflowerblue"      => 0x6495ed,
    "cornsilk"            => 0xfff8dc,
    "cornsilk1"           => 0xfff8dc,
    "cornsilk2"           => 0xeee8cd,
    "cornsilk3"           => 0xcdc8b1,
    "cornsilk4"           => 0x8b8878,
    "cyan"                => 0x000000,
    "cyan1"               => 0x000000,
    "cyan2"               => 0x000000,
    "cyan3"               => 0x000000,
    "cyan4"               => 0x000000,
    "dark blue"           => 0x000000,
    "dark cyan"           => 0x000000,
    "dark goldenrod"      => 0xb88600,
    "dark gray"           => 0xa9a9a9,
    "dark green"          => 0x000000,
    "dark grey"           => 0xa9a9a9,
    "dark khaki"          => 0xbdb76b,
    "dark magenta"        => 0x8b0000,
    "dark olive green"    => 0x00556b,
    "dark orange"         => 0xff8c00,
    "dark orchid"         => 0x990032,
    "dark red"            => 0x8b0000,
    "dark salmon"         => 0xe9967a,
    "dark sea green"      => 0x8fbc8f,
    "dark slate blue"     => 0x004800,
    "dark slate gray"     => 0x002f00,
    "dark slate grey"     => 0x002f00,
    "dark turquoise"      => 0x000000,
    "dark violet"         => 0x940000,
    "darkblue"            => 0x000000,
    "darkcyan"            => 0x000000,
    "darkgoldenrod"       => 0xb88600,
    "darkgoldenrod1"      => 0xffb900,
    "darkgoldenrod2"      => 0xeead00,
    "darkgoldenrod3"      => 0xcd9500,
    "darkgoldenrod4"      => 0x8b6500,
    "darkgray"            => 0xa9a9a9,
    "darkgreen"           => 0x000000,
    "darkgrey"            => 0xa9a9a9,
    "darkkhaki"           => 0xbdb76b,
    "darkmagenta"         => 0x8b0000,
    "darkolivegreen"      => 0x00556b,
    "darkolivegreen1"     => 0xcaff70,
    "darkolivegreen2"     => 0xbcee68,
    "darkolivegreen3"     => 0xa2cd00,
    "darkolivegreen4"     => 0x6e8b00,
    "darkorange"          => 0xff8c00,
    "darkorange1"         => 0xff7f00,
    "darkorange2"         => 0xee7600,
    "darkorange3"         => 0xcd6600,
    "darkorange4"         => 0x8b0045,
    "darkorchid"          => 0x990032,
    "darkorchid1"         => 0xbf003e,
    "darkorchid2"         => 0xb2003a,
    "darkorchid3"         => 0x9a0032,
    "darkorchid4"         => 0x680022,
    "darkred"             => 0x8b0000,
    "darksalmon"          => 0xe9967a,
    "darkseagreen"        => 0x8fbc8f,
    "darkseagreen1"       => 0xc1ffc1,
    "darkseagreen2"       => 0xb4eeb4,
    "darkseagreen3"       => 0x9bcd9b,
    "darkseagreen4"       => 0x698b69,
    "darkslateblue"       => 0x004800,
    "darkslategray"       => 0x002f00,
    "darkslategray1"      => 0x97ffff,
    "darkslategray2"      => 0x8deeee,
    "darkslategray3"      => 0x79cdcd,
    "darkslategray4"      => 0x00528b,
    "darkslategrey"       => 0x002f00,
    "darkturquoise"       => 0x000000,
    "darkviolet"          => 0x940000,
    "deep pink"           => 0xff0014,
    "deep sky blue"       => 0x000000,
    "deeppink"            => 0xff0014,
    "deeppink1"           => 0xff0014,
    "deeppink2"           => 0xee0012,
    "deeppink3"           => 0xcd0010,
    "deeppink4"           => 0x8b000a,
    "deepskyblue"         => 0x000000,
    "deepskyblue1"        => 0x000000,
    "deepskyblue2"        => 0x000000,
    "deepskyblue3"        => 0x000000,
    "deepskyblue4"        => 0x000000,
    "dim gray"            => 0x696969,
    "dim grey"            => 0x696969,
    "dimgray"             => 0x696969,
    "dimgrey"             => 0x696969,
    "dodger blue"         => 0x001e90,
    "dodgerblue"          => 0x001e90,
    "dodgerblue1"         => 0x001e90,
    "dodgerblue2"         => 0x001c86,
    "dodgerblue3"         => 0x001874,
    "dodgerblue4"         => 0x001000,
    "firebrick"           => 0xb20022,
    "firebrick1"          => 0xff0030,
    "firebrick2"          => 0xee002c,
    "firebrick3"          => 0xcd0026,
    "firebrick4"          => 0x8b001a,
    "floral white"        => 0xfffaf0,
    "floralwhite"         => 0xfffaf0,
    "forest green"        => 0x00228b,
    "forestgreen"         => 0x00228b,
    "gainsboro"           => 0xdcdcdc,
    "ghost white"         => 0xf8f8ff,
    "ghostwhite"          => 0xf8f8ff,
    "gold"                => 0xffd700,
    "gold1"               => 0xffd700,
    "gold2"               => 0xeec900,
    "gold3"               => 0xcdad00,
    "gold4"               => 0x8b7500,
    "goldenrod"           => 0xdaa500,
    "goldenrod1"          => 0xffc100,
    "goldenrod2"          => 0xeeb400,
    "goldenrod3"          => 0xcd9b00,
    "goldenrod4"          => 0x8b6900,
    "gray"                => 0xbebebe,
    "gray0"               => 0x000000,
    "gray1"               => 0x000003,
    "gray10"              => 0x001a00,
    "gray100"             => 0xffffff,
    "gray11"              => 0x001c00,
    "gray12"              => 0x001f00,
    "gray13"              => 0x002100,
    "gray14"              => 0x002400,
    "gray15"              => 0x002600,
    "gray16"              => 0x002900,
    "gray17"              => 0x002b00,
    "gray18"              => 0x002e00,
    "gray19"              => 0x003000,
    "gray2"               => 0x000005,
    "gray20"              => 0x003300,
    "gray21"              => 0x003600,
    "gray22"              => 0x003800,
    "gray23"              => 0x003b00,
    "gray24"              => 0x003d00,
    "gray25"              => 0x004000,
    "gray26"              => 0x004200,
    "gray27"              => 0x004500,
    "gray28"              => 0x004700,
    "gray29"              => 0x004a00,
    "gray3"               => 0x000008,
    "gray30"              => 0x004d00,
    "gray31"              => 0x004f00,
    "gray32"              => 0x005200,
    "gray33"              => 0x005400,
    "gray34"              => 0x005700,
    "gray35"              => 0x005900,
    "gray36"              => 0x005c00,
    "gray37"              => 0x005e00,
    "gray38"              => 0x006100,
    "gray39"              => 0x006300,
    "gray4"               => 0x000a00,
    "gray40"              => 0x666666,
    "gray41"              => 0x696969,
    "gray42"              => 0x6b6b6b,
    "gray43"              => 0x6e6e6e,
    "gray44"              => 0x707070,
    "gray45"              => 0x737373,
    "gray46"              => 0x757575,
    "gray47"              => 0x787878,
    "gray48"              => 0x7a7a7a,
    "gray49"              => 0x7d7d7d,
    "gray5"               => 0x000d00,
    "gray50"              => 0x7f7f7f,
    "gray51"              => 0x828282,
    "gray52"              => 0x858585,
    "gray53"              => 0x878787,
    "gray54"              => 0x8a8a8a,
    "gray55"              => 0x8c8c8c,
    "gray56"              => 0x8f8f8f,
    "gray57"              => 0x919191,
    "gray58"              => 0x949494,
    "gray59"              => 0x969696,
    "gray6"               => 0x000f00,
    "gray60"              => 0x999999,
    "gray61"              => 0x9c9c9c,
    "gray62"              => 0x9e9e9e,
    "gray63"              => 0xa1a1a1,
    "gray64"              => 0xa3a3a3,
    "gray65"              => 0xa6a6a6,
    "gray66"              => 0xa8a8a8,
    "gray67"              => 0xababab,
    "gray68"              => 0xadadad,
    "gray69"              => 0xb0b0b0,
    "gray7"               => 0x001200,
    "gray70"              => 0xb3b3b3,
    "gray71"              => 0xb5b5b5,
    "gray72"              => 0xb8b8b8,
    "gray73"              => 0xbababa,
    "gray74"              => 0xbdbdbd,
    "gray75"              => 0xbfbfbf,
    "gray76"              => 0xc2c2c2,
    "gray77"              => 0xc4c4c4,
    "gray78"              => 0xc7c7c7,
    "gray79"              => 0xc9c9c9,
    "gray8"               => 0x001400,
    "gray80"              => 0xcccccc,
    "gray81"              => 0xcfcfcf,
    "gray82"              => 0xd1d1d1,
    "gray83"              => 0xd4d4d4,
    "gray84"              => 0xd6d6d6,
    "gray85"              => 0xd9d9d9,
    "gray86"              => 0xdbdbdb,
    "gray87"              => 0xdedede,
    "gray88"              => 0xe0e0e0,
    "gray89"              => 0xe3e3e3,
    "gray9"               => 0x001700,
    "gray90"              => 0xe5e5e5,
    "gray91"              => 0xe8e8e8,
    "gray92"              => 0xebebeb,
    "gray93"              => 0xededed,
    "gray94"              => 0xf0f0f0,
    "gray95"              => 0xf2f2f2,
    "gray96"              => 0xf5f5f5,
    "gray97"              => 0xf7f7f7,
    "gray98"              => 0xfafafa,
    "gray99"              => 0xfcfcfc,
    "green"               => 0x000000,
    "green yellow"        => 0xadff00,
    "green1"              => 0x000000,
    "green2"              => 0x000000,
    "green3"              => 0x000000,
    "green4"              => 0x000000,
    "greenyellow"         => 0xadff00,
    "grey"                => 0xbebebe,
    "grey0"               => 0x000000,
    "grey1"               => 0x000003,
    "grey10"              => 0x001a00,
    "grey100"             => 0xffffff,
    "grey11"              => 0x001c00,
    "grey12"              => 0x001f00,
    "grey13"              => 0x002100,
    "grey14"              => 0x002400,
    "grey15"              => 0x002600,
    "grey16"              => 0x002900,
    "grey17"              => 0x002b00,
    "grey18"              => 0x002e00,
    "grey19"              => 0x003000,
    "grey2"               => 0x000005,
    "grey20"              => 0x003300,
    "grey21"              => 0x003600,
    "grey22"              => 0x003800,
    "grey23"              => 0x003b00,
    "grey24"              => 0x003d00,
    "grey25"              => 0x004000,
    "grey26"              => 0x004200,
    "grey27"              => 0x004500,
    "grey28"              => 0x004700,
    "grey29"              => 0x004a00,
    "grey3"               => 0x000008,
    "grey30"              => 0x004d00,
    "grey31"              => 0x004f00,
    "grey32"              => 0x005200,
    "grey33"              => 0x005400,
    "grey34"              => 0x005700,
    "grey35"              => 0x005900,
    "grey36"              => 0x005c00,
    "grey37"              => 0x005e00,
    "grey38"              => 0x006100,
    "grey39"              => 0x006300,
    "grey4"               => 0x000a00,
    "grey40"              => 0x666666,
    "grey41"              => 0x696969,
    "grey42"              => 0x6b6b6b,
    "grey43"              => 0x6e6e6e,
    "grey44"              => 0x707070,
    "grey45"              => 0x737373,
    "grey46"              => 0x757575,
    "grey47"              => 0x787878,
    "grey48"              => 0x7a7a7a,
    "grey49"              => 0x7d7d7d,
    "grey5"               => 0x000d00,
    "grey50"              => 0x7f7f7f,
    "grey51"              => 0x828282,
    "grey52"              => 0x858585,
    "grey53"              => 0x878787,
    "grey54"              => 0x8a8a8a,
    "grey55"              => 0x8c8c8c,
    "grey56"              => 0x8f8f8f,
    "grey57"              => 0x919191,
    "grey58"              => 0x949494,
    "grey59"              => 0x969696,
    "grey6"               => 0x000f00,
    "grey60"              => 0x999999,
    "grey61"              => 0x9c9c9c,
    "grey62"              => 0x9e9e9e,
    "grey63"              => 0xa1a1a1,
    "grey64"              => 0xa3a3a3,
    "grey65"              => 0xa6a6a6,
    "grey66"              => 0xa8a8a8,
    "grey67"              => 0xababab,
    "grey68"              => 0xadadad,
    "grey69"              => 0xb0b0b0,
    "grey7"               => 0x001200,
    "grey70"              => 0xb3b3b3,
    "grey71"              => 0xb5b5b5,
    "grey72"              => 0xb8b8b8,
    "grey73"              => 0xbababa,
    "grey74"              => 0xbdbdbd,
    "grey75"              => 0xbfbfbf,
    "grey76"              => 0xc2c2c2,
    "grey77"              => 0xc4c4c4,
    "grey78"              => 0xc7c7c7,
    "grey79"              => 0xc9c9c9,
    "grey8"               => 0x001400,
    "grey80"              => 0xcccccc,
    "grey81"              => 0xcfcfcf,
    "grey82"              => 0xd1d1d1,
    "grey83"              => 0xd4d4d4,
    "grey84"              => 0xd6d6d6,
    "grey85"              => 0xd9d9d9,
    "grey86"              => 0xdbdbdb,
    "grey87"              => 0xdedede,
    "grey88"              => 0xe0e0e0,
    "grey89"              => 0xe3e3e3,
    "grey9"               => 0x001700,
    "grey90"              => 0xe5e5e5,
    "grey91"              => 0xe8e8e8,
    "grey92"              => 0xebebeb,
    "grey93"              => 0xededed,
    "grey94"              => 0xf0f0f0,
    "grey95"              => 0xf2f2f2,
    "grey96"              => 0xf5f5f5,
    "grey97"              => 0xf7f7f7,
    "grey98"              => 0xfafafa,
    "grey99"              => 0xfcfcfc,
    "honeydew"            => 0xf0fff0,
    "honeydew1"           => 0xf0fff0,
    "honeydew2"           => 0xe0eee0,
    "honeydew3"           => 0xc1cdc1,
    "honeydew4"           => 0x838b83,
    "hot pink"            => 0xff69b4,
    "hotpink"             => 0xff69b4,
    "hotpink1"            => 0xff6eb4,
    "hotpink2"            => 0xee6aa7,
    "hotpink3"            => 0xcd0060,
    "hotpink4"            => 0x8b003a,
    "indian red"          => 0xcd005c,
    "indianred"           => 0xcd005c,
    "indianred1"          => 0xff6a6a,
    "indianred2"          => 0xee0063,
    "indianred3"          => 0xcd0055,
    "indianred4"          => 0x8b003a,
    "ivory"               => 0xfffff0,
    "ivory1"              => 0xfffff0,
    "ivory2"              => 0xeeeee0,
    "ivory3"              => 0xcdcdc1,
    "ivory4"              => 0x8b8b83,
    "khaki"               => 0xf0e68c,
    "khaki1"              => 0xfff68f,
    "khaki2"              => 0xeee685,
    "khaki3"              => 0xcdc673,
    "khaki4"              => 0x8b8600,
    "lavender"            => 0xe6e6fa,
    "lavender blush"      => 0xfff0f5,
    "lavenderblush"       => 0xfff0f5,
    "lavenderblush1"      => 0xfff0f5,
    "lavenderblush2"      => 0xeee0e5,
    "lavenderblush3"      => 0xcdc1c5,
    "lavenderblush4"      => 0x8b8386,
    "lawn green"          => 0x7cfc00,
    "lawngreen"           => 0x7cfc00,
    "lemon chiffon"       => 0xfffacd,
    "lemonchiffon"        => 0xfffacd,
    "lemonchiffon1"       => 0xfffacd,
    "lemonchiffon2"       => 0xeee9bf,
    "lemonchiffon3"       => 0xcdc9a5,
    "lemonchiffon4"       => 0x8b8970,
    "light blue"          => 0xadd8e6,
    "light coral"         => 0xf08080,
    "light cyan"          => 0xe0ffff,
    "light goldenrod"     => 0xeedd82,
    "light goldenrod yellow"=> 0xfafad2,
    "light gray"          => 0xd3d3d3,
    "light green"         => 0x90ee90,
    "light grey"          => 0xd3d3d3,
    "light pink"          => 0xffb6c1,
    "light salmon"        => 0xffa07a,
    "light sea green"     => 0x0020b2,
    "light sky blue"      => 0x87cefa,
    "light slate blue"    => 0x8470ff,
    "light slate gray"    => 0x778899,
    "light slate grey"    => 0x778899,
    "light steel blue"    => 0xb0c4de,
    "light yellow"        => 0xffffe0,
    "lightblue"           => 0xadd8e6,
    "lightblue1"          => 0xbfefff,
    "lightblue2"          => 0xb2dfee,
    "lightblue3"          => 0x9ac0cd,
    "lightblue4"          => 0x68838b,
    "lightcoral"          => 0xf08080,
    "lightcyan"           => 0xe0ffff,
    "lightcyan1"          => 0xe0ffff,
    "lightcyan2"          => 0xd1eeee,
    "lightcyan3"          => 0xb4cdcd,
    "lightcyan4"          => 0x7a8b8b,
    "lightgoldenrod"      => 0xeedd82,
    "lightgoldenrod1"     => 0xffec8b,
    "lightgoldenrod2"     => 0xeedc82,
    "lightgoldenrod3"     => 0xcdbe70,
    "lightgoldenrod4"     => 0x8b8100,
    "lightgoldenrodyellow"=> 0xfafad2,
    "lightgray"           => 0xd3d3d3,
    "lightgreen"          => 0x90ee90,
    "lightgrey"           => 0xd3d3d3,
    "lightpink"           => 0xffb6c1,
    "lightpink1"          => 0xffaeb9,
    "lightpink2"          => 0xeea2ad,
    "lightpink3"          => 0xcd8c95,
    "lightpink4"          => 0x8b005f,
    "lightsalmon"         => 0xffa07a,
    "lightsalmon1"        => 0xffa07a,
    "lightsalmon2"        => 0xee9572,
    "lightsalmon3"        => 0xcd8100,
    "lightsalmon4"        => 0x8b0057,
    "lightseagreen"       => 0x0020b2,
    "lightskyblue"        => 0x87cefa,
    "lightskyblue1"       => 0xb0e2ff,
    "lightskyblue2"       => 0xa4d3ee,
    "lightskyblue3"       => 0x8db6cd,
    "lightskyblue4"       => 0x00607b,
    "lightslateblue"      => 0x8470ff,
    "lightslategray"      => 0x778899,
    "lightslategrey"      => 0x778899,
    "lightsteelblue"      => 0xb0c4de,
    "lightsteelblue1"     => 0xcae1ff,
    "lightsteelblue2"     => 0xbcd2ee,
    "lightsteelblue3"     => 0xa2b5cd,
    "lightsteelblue4"     => 0x6e7b8b,
    "lightyellow"         => 0xffffe0,
    "lightyellow1"        => 0xffffe0,
    "lightyellow2"        => 0xeeeed1,
    "lightyellow3"        => 0xcdcdb4,
    "lightyellow4"        => 0x8b8b7a,
    "lime green"          => 0x0032cd,
    "limegreen"           => 0x0032cd,
    "linen"               => 0xfaf0e6,
    "magenta"             => 0xff0000,
    "magenta1"            => 0xff0000,
    "magenta2"            => 0xee0000,
    "magenta3"            => 0xcd0000,
    "magenta4"            => 0x8b0000,
    "maroon"              => 0xb00030,
    "maroon1"             => 0xff0034,
    "maroon2"             => 0xee0030,
    "maroon3"             => 0xcd0029,
    "maroon4"             => 0x8b001c,
    "medium aquamarine"   => 0x66cdaa,
    "medium blue"         => 0x000000,
    "medium orchid"       => 0xba0055,
    "medium purple"       => 0x9370db,
    "medium sea green"    => 0x003cb3,
    "medium slate blue"   => 0x7b68ee,
    "medium spring green" => 0x000000,
    "medium turquoise"    => 0x0048d1,
    "medium violet red"   => 0xc70015,
    "mediumaquamarine"    => 0x66cdaa,
    "mediumblue"          => 0x000000,
    "mediumorchid"        => 0xba0055,
    "mediumorchid1"       => 0xe066ff,
    "mediumorchid2"       => 0xd1005f,
    "mediumorchid3"       => 0xb40052,
    "mediumorchid4"       => 0x7a0037,
    "mediumpurple"        => 0x9370db,
    "mediumpurple1"       => 0xab82ff,
    "mediumpurple2"       => 0x9f79ee,
    "mediumpurple3"       => 0x8968cd,
    "mediumpurple4"       => 0x005d00,
    "mediumseagreen"      => 0x003cb3,
    "mediumslateblue"     => 0x7b68ee,
    "mediumspringgreen"   => 0x000000,
    "mediumturquoise"     => 0x0048d1,
    "mediumvioletred"     => 0xc70015,
    "midnight blue"       => 0x001900,
    "midnightblue"        => 0x001900,
    "mint cream"          => 0xf5fffa,
    "mintcream"           => 0xf5fffa,
    "misty rose"          => 0xffe4e1,
    "mistyrose"           => 0xffe4e1,
    "mistyrose1"          => 0xffe4e1,
    "mistyrose2"          => 0xeed5d2,
    "mistyrose3"          => 0xcdb7b5,
    "mistyrose4"          => 0x8b7d7b,
    "moccasin"            => 0xffe4b5,
    "navajo white"        => 0xffdead,
    "navajowhite"         => 0xffdead,
    "navajowhite1"        => 0xffdead,
    "navajowhite2"        => 0xeecfa1,
    "navajowhite3"        => 0xcdb38b,
    "navajowhite4"        => 0x8b7900,
    "navy"                => 0x000000,
    "navy blue"           => 0x000000,
    "navyblue"            => 0x000000,
    "old lace"            => 0xfdf5e6,
    "oldlace"             => 0xfdf5e6,
    "olive drab"          => 0x6b8e00,
    "olivedrab"           => 0x6b8e00,
    "olivedrab1"          => 0xc0ff00,
    "olivedrab2"          => 0xb3ee00,
    "olivedrab3"          => 0x9acd00,
    "olivedrab4"          => 0x698b00,
    "orange"              => 0xffa500,
    "orange red"          => 0xff0045,
    "orange1"             => 0xffa500,
    "orange2"             => 0xee9a00,
    "orange3"             => 0xcd8500,
    "orange4"             => 0x8b005a,
    "orangered"           => 0xff0045,
    "orangered1"          => 0xff0045,
    "orangered2"          => 0xee0040,
    "orangered3"          => 0xcd0037,
    "orangered4"          => 0x8b0025,
    "orchid"              => 0xda70d6,
    "orchid1"             => 0xff83fa,
    "orchid2"             => 0xee7ae9,
    "orchid3"             => 0xcd69c9,
    "orchid4"             => 0x8b0047,
    "pale goldenrod"      => 0xeee8aa,
    "pale green"          => 0x98fb98,
    "pale turquoise"      => 0xafeeee,
    "pale violet red"     => 0xdb7093,
    "palegoldenrod"       => 0xeee8aa,
    "palegreen"           => 0x98fb98,
    "palegreen1"          => 0x9aff9a,
    "palegreen2"          => 0x90ee90,
    "palegreen3"          => 0x7ccd7c,
    "palegreen4"          => 0x00548b,
    "paleturquoise"       => 0xafeeee,
    "paleturquoise1"      => 0xbbffff,
    "paleturquoise2"      => 0xaeeeee,
    "paleturquoise3"      => 0x96cdcd,
    "paleturquoise4"      => 0x668b8b,
    "palevioletred"       => 0xdb7093,
    "palevioletred1"      => 0xff82ab,
    "palevioletred2"      => 0xee799f,
    "palevioletred3"      => 0xcd6889,
    "palevioletred4"      => 0x8b0047,
    "papaya whip"         => 0xffefd5,
    "papayawhip"          => 0xffefd5,
    "peach puff"          => 0xffdab9,
    "peachpuff"           => 0xffdab9,
    "peachpuff1"          => 0xffdab9,
    "peachpuff2"          => 0xeecbad,
    "peachpuff3"          => 0xcdaf95,
    "peachpuff4"          => 0x8b7765,
    "peru"                => 0xcd8500,
    "pink"                => 0xffc0cb,
    "pink1"               => 0xffb5c5,
    "pink2"               => 0xeea9b8,
    "pink3"               => 0xcd919e,
    "pink4"               => 0x8b0063,
    "plum"                => 0xdda0dd,
    "plum1"               => 0xffbbff,
    "plum2"               => 0xeeaeee,
    "plum3"               => 0xcd96cd,
    "plum4"               => 0x8b668b,
    "powder blue"         => 0xb0e0e6,
    "powderblue"          => 0xb0e0e6,
    "purple"              => 0xa00020,
    "purple1"             => 0x9b0030,
    "purple2"             => 0x91002c,
    "purple3"             => 0x7d0026,
    "purple4"             => 0x005500,
    "red"                 => 0xff0000,
    "red1"                => 0xff0000,
    "red2"                => 0xee0000,
    "red3"                => 0xcd0000,
    "red4"                => 0x8b0000,
    "rosy brown"          => 0xbc8f8f,
    "rosybrown"           => 0xbc8f8f,
    "rosybrown1"          => 0xffc1c1,
    "rosybrown2"          => 0xeeb4b4,
    "rosybrown3"          => 0xcd9b9b,
    "rosybrown4"          => 0x8b6969,
    "royal blue"          => 0x004169,
    "royalblue"           => 0x004169,
    "royalblue1"          => 0x004876,
    "royalblue2"          => 0x00436e,
    "royalblue3"          => 0x003a00,
    "royalblue4"          => 0x002700,
    "saddle brown"        => 0x8b0045,
    "saddlebrown"         => 0x8b0045,
    "salmon"              => 0xfa8072,
    "salmon1"             => 0xff8c69,
    "salmon2"             => 0xee8200,
    "salmon3"             => 0xcd7000,
    "salmon4"             => 0x8b004c,
    "sandy brown"         => 0xf4a400,
    "sandybrown"          => 0xf4a400,
    "sea green"           => 0x002e8b,
    "seagreen"            => 0x002e8b,
    "seagreen1"           => 0x0054ff,
    "seagreen2"           => 0x004eee,
    "seagreen3"           => 0x0043cd,
    "seagreen4"           => 0x002e8b,
    "seashell"            => 0xfff5ee,
    "seashell1"           => 0xfff5ee,
    "seashell2"           => 0xeee5de,
    "seashell3"           => 0xcdc5bf,
    "seashell4"           => 0x8b8682,
    "sienna"              => 0xa00052,
    "sienna1"             => 0xff8200,
    "sienna2"             => 0xee7900,
    "sienna3"             => 0xcd6800,
    "sienna4"             => 0x8b0047,
    "sky blue"            => 0x87ceeb,
    "skyblue"             => 0x87ceeb,
    "skyblue1"            => 0x87ceff,
    "skyblue2"            => 0x7ec0ee,
    "skyblue3"            => 0x6ca6cd,
    "skyblue4"            => 0x004a70,
    "slate blue"          => 0x6a005a,
    "slate gray"          => 0x708090,
    "slate grey"          => 0x708090,
    "slateblue"           => 0x6a005a,
    "slateblue1"          => 0x836fff,
    "slateblue2"          => 0x7a67ee,
    "slateblue3"          => 0x690059,
    "slateblue4"          => 0x004700,
    "slategray"           => 0x708090,
    "slategray1"          => 0xc6e2ff,
    "slategray2"          => 0xb9d3ee,
    "slategray3"          => 0x9fb6cd,
    "slategray4"          => 0x6c7b8b,
    "slategrey"           => 0x708090,
    "snow"                => 0xfffafa,
    "snow1"               => 0xfffafa,
    "snow2"               => 0xeee9e9,
    "snow3"               => 0xcdc9c9,
    "snow4"               => 0x8b8989,
    "spring green"        => 0x000000,
    "springgreen"         => 0x000000,
    "springgreen1"        => 0x000000,
    "springgreen2"        => 0x000000,
    "springgreen3"        => 0x000000,
    "springgreen4"        => 0x000000,
    "steel blue"          => 0x004682,
    "steelblue"           => 0x004682,
    "steelblue1"          => 0x0063b8,
    "steelblue2"          => 0x005cac,
    "steelblue3"          => 0x004f94,
    "steelblue4"          => 0x003664,
    "tan"                 => 0xd2b48c,
    "tan1"                => 0xffa500,
    "tan2"                => 0xee9a00,
    "tan3"                => 0xcd8500,
    "tan4"                => 0x8b005a,
    "thistle"             => 0xd8bfd8,
    "thistle1"            => 0xffe1ff,
    "thistle2"            => 0xeed2ee,
    "thistle3"            => 0xcdb5cd,
    "thistle4"            => 0x8b7b8b,
    "tomato"              => 0xff0063,
    "tomato1"             => 0xff0063,
    "tomato2"             => 0xee005c,
    "tomato3"             => 0xcd004f,
    "tomato4"             => 0x8b0036,
    "turquoise"           => 0x0040e0,
    "turquoise1"          => 0x000000,
    "turquoise2"          => 0x000000,
    "turquoise3"          => 0x000000,
    "turquoise4"          => 0x000000,
    "violet"              => 0xee82ee,
    "violet red"          => 0xd00020,
    "violetred"           => 0xd00020,
    "violetred1"          => 0xff003e,
    "violetred2"          => 0xee003a,
    "violetred3"          => 0xcd0032,
    "violetred4"          => 0x8b0022,
    "wheat"               => 0xf5deb3,
    "wheat1"              => 0xffe7ba,
    "wheat2"              => 0xeed8ae,
    "wheat3"              => 0xcdba96,
    "wheat4"              => 0x8b7e66,
    "white"               => 0xffffff,
    "white smoke"         => 0xf5f5f5,
    "whitesmoke"          => 0xf5f5f5,
    "yellow"              => 0xffff00,
    "yellow green"        => 0x9acd00,
    "yellow1"             => 0xffff00,
    "yellow2"             => 0xeeee00,
    "yellow3"             => 0xcdcd00,
    "yellow4"             => 0x8b8b00,
    "yellowgreen"         => 0x9acd00,
  };
}

1;

__END__
